/**
 * Ensures the value of the current field (the one the validator is on) matches the one of the target field.
 * @param target - any other field
 * @returns a validator function that will be run by the smart form during the client-side validation stage
 * @public
 */
export const mustMatch = (target) => {
    return (data, path, label) => {
        if (!path?.length || !target?.length || !data)
            return [];
        const value1 = data?.[target];
        const value2 = data?.[path];
        if (!value1?.length || !value2?.length || value1 === value2)
            return [];
        return [
            {
                instancePath: `/${path}`,
                message: `Needs to match ${target}`,
                schemaPath: '',
                keyword: '',
                params: {},
            },
        ];
    };
};
